Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(30)

Unified Diff: src/arm/builtins-arm.cc

Issue 6992072: Implement set trap for proxies, and revamp class hierarchy in preparation (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/arm/builtins-arm.cc
diff --git a/src/arm/builtins-arm.cc b/src/arm/builtins-arm.cc
index 1b2b919305526b745bb7d47154b775effb993885..5e06f81c38f36874aa680bf28c54ef9859984346 100644
--- a/src/arm/builtins-arm.cc
+++ b/src/arm/builtins-arm.cc
@@ -948,8 +948,8 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm,
__ b(eq, &use_receiver);
// If the type of the result (stored in its map) is less than
- // FIRST_JS_OBJECT_TYPE, it is not an object in the ECMA sense.
- __ CompareObjectType(r0, r3, r3, FIRST_JS_OBJECT_TYPE);
+ // FIRST_OBJECT_OR_FUNCTION_CLASS_TYPE, it is not an object in the ECMA sense.
Kevin Millikin (Chromium) 2011/05/26 09:31:08 Maybe the terminology is still not quite right. T
rossberg 2011/05/31 14:50:24 Changed according to your suggestion on the list.
+ __ CompareObjectType(r0, r3, r3, FIRST_OBJECT_OR_FUNCTION_CLASS_TYPE);
__ b(ge, &exit);
// Throw away the result of the constructor invocation and use the

Powered by Google App Engine
This is Rietveld 408576698